==> videosdk-1.0.0.tar.gz: README.md <==
<h1 align="center">
  <img src="https://static.zujonow.com/videosdk_logo_website_black.png"/><br/>
<p align="center">
  Video SDK Flutter<br/>
  <a href="https://videosdk.live/">videosdk.live</a>
</p>
</h1>

<!-- ![video-sdk-logo.png](https://static.videosdk.live/videosdk.live/videosdk_logo_circle_big.png) -->

[![Pub Version](https://img.shields.io/pub/v/videosdk)](https://pub.dev/packages/videosdk)
[![Documentation](https://img.shields.io/badge/Read-Documentation-blue)](https://docs.videosdk.live/docs/guide/video-and-audio-calling-api-sdk/flutter-sdk)
[![Discord](https://img.shields.io/discord/876774498798551130?label=Join%20on%20Discord)](https://discord.gg/kgAvyxtTxv)
[![Register](https://img.shields.io/badge/Contact-Know%20More-blue)](https://videosdk.live/contact)

# Video SDK Flutter

Video SDK Flutter to simply integrate Audio & Video Calling API or Live Video Streaming API to your app with just a few lines of code.

## Functionality

| Feature      |      Android       |                iOS |         Web |
| ------------ | :----------------: | -----------------: | ----------: |
| Audio/Video  | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| Recorder     | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| RTMP Live    | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| Simulcast    | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| Screen Share | :heavy_check_mark: |        :hourglass: | :hourglass: |
| Data Channel |    :hourglass:     |        :hourglass: | :hourglass: |

## Getting Started

### Setup Guide

Add `videosdk` as a [dependency in your pubspec.yaml file](https://flutter.io/using-packages/).

## Android Setup

### Update AndroidManifest.xml file for the permissions

Ensure the following permission is present in your Android Manifest file, located in `<project root>/android/app/src/main/AndroidManifest.xml`:

```xml
<uses-feature android:name="android.hardware.camera" />
<uses-feature android:name="android.hardware.camera.autofocus" />
<uses-permission android:name="android.permission.INTERNET"/>
<uses-permission android:name="android.permission.CAMERA" />
<uses-permission android:name="android.permission.RECORD_AUDIO" />
<uses-permission android:name="android.permission.ACCESS_NETWORK_STATE" />
<uses-permission android:name="android.permission.CHANGE_NETWORK_STATE" />
<uses-permission android:name="android.permission.MODIFY_AUDIO_SETTINGS" />
<uses-permission android:name="android.permission.FOREGROUND_SERVICE"/>
<uses-permission android:name="android.permission.WAKE_LOCK" />
```

If you need to use a Bluetooth device, please add:

```xml
<uses-permission android:name="android.permission.BLUETOOTH" />
<uses-permission android:name="android.permission.BLUETOOTH_ADMIN" />
```

The Flutter project template adds it, so it may already be there.

Also you will need to set your build settings to Java 8, because official WebRTC jar now uses static methods in `EglBase` interface. Just add this to your app level `build.gradle`:

```js
android {
    //...
    compileOptions {
        sourceCompatibility JavaVersion.VERSION_1_8
        targetCompatibility JavaVersion.VERSION_1_8
    }
}
```

> If necessary, in the same `build.gradle` you will need to increase `minSdkVersion` of `defaultConfig` up to `23` (currently default Flutter generator set it to `16`).

> If necessary, in the same `build.gradle` you will need to increase `compileSdkVersion` and `targetSdkVersion` up to `31` (currently default Flutter generator set it to `30`).

````

## iOS Setup

Add the following entry to your Info.plist file, located in `<project root>`/ios/Runner/Info.plist:

```xml
<key>NSCameraUsageDescription</key>
<string>$(PRODUCT_NAME) Camera Usage!</string>
<key>NSMicrophoneUsageDescription</key>
<string>$(PRODUCT_NAME) Microphone Usage!</string>
````

This entry allows your app to access camera and microphone.

## Import it

Now in your Dart code, you can use:

```js
import "package:videosdk/videosdk.dart";
```

==> videosdk-1.0.8.tar.gz: README.md <==
<p align="center">
  <a href="https://videosdk.live">
  <img src="https://static.videosdk.live/videosdk_logo_website_black.png"/><br/>
  </a>
</p>

<!-- ![video-sdk-logo.png](https://static.videosdk.live/videosdk.live/videosdk_logo_circle_big.png) -->

<p align="center">
  <a href="https://discord.gg/kgAvyxtTxv">
    <img src="https://img.shields.io/discord/734858252939952248?logo=discord&style=flat" />
  </a>
<a href="https://pub.dev/packages/videosdk">
   <img src="https://img.shields.io/pub/likes/videosdk?label=Like&logo=Pubev&style=flat" alt="Pubev badge"/>
</a>
  <a href="https://twitter.com/intent/follow?original_referer=https%3A%2F%2Fpublish.twitter.com%2F&ref_src=twsrc%5Etfw%7Ctwcamp%5Ebuttonembed%7Ctwterm%5Efollow%7Ctwgr%5Evideo_sdk&screen_name=video_sdk">
    <img src="https://img.shields.io/twitter/follow/video_sdk?label=Twitter&logo=twitter&style=flat" />
  </a>
  <a href="http://youtube.com/videosdk?sub_confirmation=1">
    <img src="https://img.shields.io/youtube/channel/subscribers/UCuY7JzXnpp874oa7uQbUwsA?logo=Youtube&style=flat" />
  </a>
  <a href="https://github.com/videosdk-live/videosdk.live?tab=stars">
    <img src="https://img.shields.io/github/stars/videosdk-live/videosdk.live?label=Stars&logo=GitHub&style=flat" alt="GitHub badge" />
  </a>
</p>

# Video SDK Flutter

Video SDK Flutter to simply integrate Audio & Video Calling API or Live Video Streaming API to your app with just a few lines of code.

## Functionality

| Feature      |      Android       |                iOS |         Web |
| ------------ | :----------------: | -----------------: | ----------: |
| Audio/Video  | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| Recorder     | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| RTMP Live    | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| Simulcast    | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| Screen Share | :heavy_check_mark: | :heavy_check_mark: | :hourglass: |
| Data Channel |    :hourglass:     |        :hourglass: | :hourglass: |

## Getting Started

### Setup Guide

Add `videosdk` as a [dependency in your pubspec.yaml file](https://flutter.io/using-packages/).

## Android Setup

### Update AndroidManifest.xml file for the permissions

Ensure the following permission is present in your Android Manifest file, located in `<project root>/android/app/src/main/AndroidManifest.xml`:

```xml
<uses-feature android:name="android.hardware.camera" />
<uses-feature android:name="android.hardware.camera.autofocus" />
<uses-permission android:name="android.permission.INTERNET"/>
<uses-permission android:name="android.permission.CAMERA" />
<uses-permission android:name="android.permission.RECORD_AUDIO" />
<uses-permission android:name="android.permission.ACCESS_NETWORK_STATE" />
<uses-permission android:name="android.permission.CHANGE_NETWORK_STATE" />
<uses-permission android:name="android.permission.MODIFY_AUDIO_SETTINGS" />
<uses-permission android:name="android.permission.FOREGROUND_SERVICE"/>
<uses-permission android:name="android.permission.WAKE_LOCK" />
```

If you need to use a Bluetooth device, please add:

```xml
<uses-permission android:name="android.permission.BLUETOOTH" />
<uses-permission android:name="android.permission.BLUETOOTH_ADMIN" />
```

The Flutter project template adds it, so it may already be there.

Also you will need to set your build settings to Java 8, because official WebRTC jar now uses static methods in `EglBase` interface. Just add this to your app level `build.gradle`:

```js
android {
    //...
    compileOptions {
        sourceCompatibility JavaVersion.VERSION_1_8
        targetCompatibility JavaVersion.VERSION_1_8
    }
}
```

> If necessary, in the same `build.gradle` you will need to increase `minSdkVersion` of `defaultConfig` up to `23` (currently default Flutter generator set it to `16`).

> If necessary, in the same `build.gradle` you will need to increase `compileSdkVersion` and `targetSdkVersion` up to `31` (currently default Flutter generator set it to `30`).

````

## iOS Setup

Add the following entry to your Info.plist file, located in `<project root>`/ios/Runner/Info.plist:

```xml
<key>NSCameraUsageDescription</key>
<string>$(PRODUCT_NAME) Camera Usage!</string>
<key>NSMicrophoneUsageDescription</key>
<string>$(PRODUCT_NAME) Microphone Usage!</string>
````

This entry allows your app to access camera and microphone.

## Import it

Now in your Dart code, you can use:

```js
import "package:videosdk/videosdk.dart";
```
